==> RsCMX_Signaling-4.0.120.tar.gz: RsCMX_Signaling-4.0.120/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Power/Uplink/ZczConfig.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZczConfigCls:
	"""ZczConfig commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zczConfig", core, parent)

	def set(self, cell_name: str, config: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig \n
		Snippet: driver.configure.signaling.nradio.cell.power.uplink.zczConfig.set(cell_name = '1', config = 1) \n
		Sets the parameter 'zeroCorrelationZoneConfig', signaled to the UE. \n
			:param cell_name: No help available
			:param config: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('config', config, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.power.uplink.zczConfig.get(cell_name = '1') \n
		Sets the parameter 'zeroCorrelationZoneConfig', signaled to the UE. \n
			:param cell_name: No help available
			:return: config: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig? {param}')
		return Conversions.str_to_int(response)

==> RsCMX_Signaling-7.70.0.tar.gz: RsCMX_Signaling-7.70.0/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Power/Uplink/ZczConfig.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZczConfigCls:
	"""ZczConfig commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zczConfig", core, parent)

	def set(self, cell_name: str, config: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig \n
		Snippet: driver.configure.signaling.nradio.cell.power.uplink.zczConfig.set(cell_name = 'abc', config = 1) \n
		Sets the parameter 'zeroCorrelationZoneConfig', signaled to the UE. \n
			:param cell_name: No help available
			:param config: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('config', config, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.power.uplink.zczConfig.get(cell_name = 'abc') \n
		Sets the parameter 'zeroCorrelationZoneConfig', signaled to the UE. \n
			:param cell_name: No help available
			:return: config: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:POWer:UL:ZCZConfig? {param}')
		return Conversions.str_to_int(response)
